@@ -1,6 +1,8 @@
 from lettuce import before, world, after
 from salad.logger import logger
 
+old_database_name = None
+
 try:
     from django.core.management import call_command
     from django.conf import settings
@@ -12,17 +14,15 @@ try:
     except:
         USE_SOUTH = False
 
-    @before.all
-    def setup_database():
+    @before.runserver
+    def setup_database(actual_server):
         logger.info("Setting up a test database ...\n")
 
         if settings.DATABASES["default"]["ENGINE"] != "django.db.backends.sqlite3":
             from django.db import connection
-            database_name = settings.DATABASES["default"]["NAME"]
-            cursor = connection.cursor()
-            cursor.execute("DROP DATABASE %s" % database_name)
-            cursor.execute("CREATE DATABASE %s" % database_name)
-            connection.close()
+            global old_database_name
+            old_database_name = settings.DATABASES["default"]["NAME"]
+            connection.creation.create_test_db()
         else:
             # connection.settings_dict["NAME"] = ":memory:"
             pass
@@ -36,10 +36,13 @@ try:
         call_command('syncdb', interactive=False, verbosity=0)
         call_command('flush', interactive=False, verbosity=0)
 
-    @after.all
-    def teardown_database(total):
+    @after.runserver
+    def teardown_database(actual_server):
         logger.info("Destroying test database ...\n")
         world.test_runner.teardown_test_environment()
+        if settings.DATABASES["default"]["ENGINE"] != "django.db.backends.sqlite3":
+            from django.db import connection
+            connection.creation.destroy_test_db(old_database_name)
 
     @after.each_feature
     def reset_data(scenario):
